from alegra.resources import Contact
from alegra.resources import Invoice
from alegra.resources import Item
from alegra.resources import Retention
from alegra.resources import Tax


user = None
token = None
api_base = "https://api.alegra.com/api"
api_version = "v1"
